# Alphaz

## Introduction: _The Last Markdown Editor, Ever_

[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)]()

Alphaz is a backend toolbox/framework based on a combination between Flask, SqlAlchemy and a multitude of other libraries.

> The overriding goal for Alphaz is to ease the development and easely link python backend to Angular frontend [alphaa].

## Features

-   API Routing parameters management upgrade
-   Enhanced json files configuration

## Tech

Alphaz uses a number of open source projects to work properly:

-   [Flask](https://flask.palletsprojects.com/en/1.1.x/) - a micro web framework
-   [SqlAlchemy](https://www.sqlalchemy.org/) - a database toolkit
-   [Flask-SqlAlchemy](https://flask-sqlalchemy.palletsprojects.com/en/2.x/) - an extension for Flask that adds support for SQLAlchemy

## Installation

Alphaz requires [Python](https://www.python.org/) 3+ to run.


```sh
pip install alphaz
```

## API

To start the api execute the `api.py` file

> Note: set `ALPHA_CONF` environment parameter is you want to set the environment.

Verify the deployment by navigating to your server address in your preferred browser:

```sh
127.0.0.1:<port>
```

## License

MIT

**Free Software, Hell Yeah!**

[alphaa]: https://github.com/ZAurele/alphaa
